@@ -3,7 +3,11 @@ from snowplow_tracker.subject import Subject
 from snowplow_tracker.emitters import logger, Emitter, AsyncEmitter
 from snowplow_tracker.self_describing_json import SelfDescribingJson
 from snowplow_tracker.tracker import Tracker
+from snowplow_tracker.emitter_configuration import EmitterConfiguration
+from snowplow_tracker.tracker_configuration import TrackerConfiguration
+from snowplow_tracker.snowplow import Snowplow
 from snowplow_tracker.contracts import disable_contracts, enable_contracts
+from snowplow_tracker.event_store import EventStore
 
 # celery extra
 from .celery import CeleryEmitter
