@@ -1,7 +1,7 @@
 # """
 #     typing.py
 
-#     Copyright (c) 2013-2022 Snowplow Analytics Ltd. All rights reserved.
+#     Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.
 
 #     This program is licensed to you under the Apache License Version 2.0,
 #     and you may not use this file except in compliance with the Apache License
@@ -13,10 +13,6 @@
 #     an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 #     express or implied. See the Apache License Version 2.0 for the specific
 #     language governing permissions and limitations there under.
-
-#     Authors: Anuj More, Alex Dean, Fred Blundun, Paul Boocock, Matus Tomlein
-#     Copyright: Copyright (c) 2013-2022 Snowplow Analytics Ltd
-#     License: Apache License Version 2.0
 # """
 
 from typing import Dict, List, Callable, Any, Optional, Union, Tuple
@@ -29,10 +25,29 @@ JsonEncoderFunction = Callable[[Any], Any]
 # tracker
 FORM_NODE_NAMES = {"INPUT", "TEXTAREA", "SELECT"}
 FORM_TYPES = {
-    "button", "checkbox", "color", "date", "datetime",
-    "datetime-local", "email", "file", "hidden", "image", "month",
-    "number", "password", "radio", "range", "reset", "search",
-    "submit", "tel", "text", "time", "url", "week"
+    "button",
+    "checkbox",
+    "color",
+    "date",
+    "datetime",
+    "datetime-local",
+    "email",
+    "file",
+    "hidden",
+    "image",
+    "month",
+    "number",
+    "password",
+    "radio",
+    "range",
+    "reset",
+    "search",
+    "submit",
+    "tel",
+    "text",
+    "time",
+    "url",
+    "week",
 }
 FormNodeName = Literal["INPUT", "TEXTAREA", "SELECT"]
 ElementClasses = Union[List[str], Tuple[str, Any]]
